==> s-component-ui-1.0.4.tgz: package/es/icon/index.es.js <==
import { defineComponent as m, computed as b, openBlock as d, createElementBlock as p, normalizeClass as z, unref as a, normalizeStyle as _, renderSlot as $, createApp as g, h } from "vue";
function r(n, o, c, e) {
  return o && (n += `-${o}`), c && (n += `__${c}`), e && (n += `--${e}`), n;
}
function y(n) {
  return {
    b: (t = "") => r(n, t, "", ""),
    e: (t = "") => t ? r(n, "", t, "") : "",
    m: (t = "") => t ? r(n, "", "", t) : "",
    be: (t = "", s = "") => t && s ? r(n, t, s, "") : "",
    bm: (t = "", s = "") => t && s ? r(n, t, "", s) : "",
    em: (t = "", s = "") => t && s ? r(n, "", t, s) : "",
    bem: (t = "", s = "", l = "") => t && s && l ? r(n, t, s, l) : "",
    is: (t, s) => s ? `is-${t}` : ""
  };
}
function C(n) {
  const o = `z-${n}`;
  return y(o);
}
const B = {
  color: String,
  size: [Number, String]
}, E = /* @__PURE__ */ m({
  __name: "icon",
  props: B,
  setup(n) {
    const o = n;
    defineOptions({
      name: "s-icon"
    });
    const c = C("icon"), e = b(() => !o.size && !o.color ? {} : {
      ...o.size ? { "font-size": o.size + "px" } : {},
      ...o.color ? { color: o.color } : {}
    });
    return (u, i) => (d(), p("i", {
      class: z(a(c).b()),
      style: _(a(e))
    }, [
      $(u.$slots, "default")
    ], 6));
  }
});
function I(n) {
  const o = g(n), c = document.createElement("div");
  return document.body.appendChild(c), {
    instance: o.mount(c),
    unmount() {
      o.unmount(), document.body.removeChild(c);
    }
  };
}
function v(n) {
  return (o = {}) => {
    const { unmount: c } = I({
      setup() {
        const e = {
          dialogVisible: !0,
          close: () => {
            c();
          }
        };
        return () => h(n, { ...e, ...o });
      }
    });
  };
}
function P(n, o = !1, c) {
  return n.install = (e) => {
    const { name: u } = n;
    u && (c = u), e.component(c, n), o && (e.config.globalProperties["$" + c] = v(n));
  }, n;
}
const O = P(E);
export {
  O as default,
  B as iconProps
};

==> s-component-ui-1.0.6.tgz: package/es/icon/index.es.js <==
import { defineComponent as b, computed as m, openBlock as d, createElementBlock as z, normalizeClass as _, unref as a, normalizeStyle as p, renderSlot as $, createApp as g, h } from "vue";
function r(n, o, c, e) {
  return o && (n += `-${o}`), c && (n += `__${c}`), e && (n += `--${e}`), n;
}
function y(n) {
  return {
    b: (t = "") => r(n, t, "", ""),
    e: (t = "") => t ? r(n, "", t, "") : "",
    m: (t = "") => t ? r(n, "", "", t) : "",
    be: (t = "", s = "") => t && s ? r(n, t, s, "") : "",
    bm: (t = "", s = "") => t && s ? r(n, t, "", s) : "",
    em: (t = "", s = "") => t && s ? r(n, "", t, s) : "",
    bem: (t = "", s = "", l = "") => t && s && l ? r(n, t, s, l) : "",
    is: (t, s) => s ? `is-${t}` : ""
  };
}
function C(n) {
  const o = `z-${n}`;
  return y(o);
}
const B = {
  color: String,
  size: [Number, String]
}, E = /* @__PURE__ */ b({
  __name: "icon",
  props: B,
  setup(n) {
    const o = n, c = C("icon"), e = m(() => !o.size && !o.color ? {} : {
      ...o.size ? { "font-size": o.size + "px" } : {},
      ...o.color ? { color: o.color } : {}
    });
    return (u, i) => (d(), z("i", {
      class: _(a(c).b()),
      style: p(a(e))
    }, [
      $(u.$slots, "default")
    ], 6));
  }
});
function I(n) {
  const o = g(n), c = document.createElement("div");
  return document.body.appendChild(c), {
    instance: o.mount(c),
    unmount() {
      o.unmount(), document.body.removeChild(c);
    }
  };
}
function v(n) {
  return (o = {}) => {
    const { unmount: c } = I({
      setup() {
        const e = {
          dialogVisible: !0,
          close: () => {
            c();
          }
        };
        return () => h(n, { ...e, ...o });
      }
    });
  };
}
function P(n, o = !1, c) {
  return n.install = (e) => {
    const { name: u } = n;
    u && (c = u), e.component(c, n), o && (e.config.globalProperties["$" + c] = v(n));
  }, n;
}
const S = P(E, !1, "s-icon");
export {
  S as default,
  B as iconProps
};
